@@ -27,11 +27,11 @@ enable_plugin barbican https://git.openstack.org/openstack/barbican
 # Sort out our gate args
 . $(dirname "$0")/decode_args.sh
 
-# Note: The check for OVH instances is temporary until they resolve the
-# KVM failures as logged here:
+# Note: The check for OVH and limestone instances is temporary until they
+# resolve the KVM failures as logged here:
 # https://bugzilla.kernel.org/show_bug.cgi?id=192521
 # However, this may be resolved at OVH before the kernel bug is resolved.
-if $(egrep --quiet '(vmx|svm)' /proc/cpuinfo) && [[ ! $(hostname) =~ "ovh" ]]; then
+if egrep --quiet '(vmx|svm)' /proc/cpuinfo; then
     export DEVSTACK_GATE_LIBVIRT_TYPE=kvm
 fi
 
@@ -39,6 +39,13 @@ function _setup_octavia {
     export DEVSTACK_LOCAL_CONFIG+="
         enable_plugin octavia https://git.openstack.org/openstack/octavia
         "
+    if [[ "$lbaasenv" == "proxy_octavia" ]]; then
+        export DEVSTACK_LOCAL_CONFIG+="
+            enable_service q-api-ha
+            export PROXY_OCTAVIA=True
+            export OCTAVIA_USE_LEGACY_RBAC=True
+            "
+    fi
     # Use infra's cached version of the file
     if [ -f /opt/stack/new/devstack/files/get-pip.py ]; then
             export DEVSTACK_LOCAL_CONFIG+="
